# docugami-langchain

This package contains the LangChain integrations for Docugami.

## Installation

To install with pip:

`pip install docugami-langchain`

To install with poetry:

`poetry add docugami-langchain`

## Development and Testing

To install with development and testing dependencies, install as `poetry install --with test,lint,typing,codespell`.